#
# spec file for package monit
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#               Pascal Bleser <pascal.bleser@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


#Compat macro for new _fillupdir macro introduced in Nov 2017
%if ! %{defined _fillupdir}
  %define _fillupdir /var/adm/fillup-templates
%endif

Name:           monit
Version:        5.25.1
Release:        lp150.1.3
Summary:        Service Manager and Monitor System
License:        AGPL-3.0
Group:          System/Monitoring
Url:            https://m%{name}.com/%{name}/#download
Source0:        https://m%{name}.com/%{name}/dist/%{name}-%{version}.tar.gz
Source1:        https://m%{name}.com/%{name}/dist/%{name}-%{version}.tar.gz.sha256
Source2:        %{name}-rpmlintrc
Source3:        %{name}.service
Source100:      %{name}-vendor-files.tar.gz
Patch1:         %{name}-better_default_monitrc.patch
Patch2:         %{name}-rundir.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
#
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  bison
BuildRequires:  flex
BuildRequires:  gcc
BuildRequires:  glibc-devel
BuildRequires:  libtool
BuildRequires:  make
BuildRequires:  openssl-devel
BuildRequires:  pam-devel

%if 0%{?suse_version} >= 1210
BuildRequires:  systemd
%{?systemd_requires}
%define has_systemd 1
%define _monit_run_dir  /run/%{name}
%else
Requires(pre):  %insserv_prereq
%define _monit_run_dir  %{_localstatedir}/run/%{name}
%endif

Obsoletes:      %{name}-beta < %{version}
Provides:       %{name}-beta = %{version}

%if "%{_vendor}" == "suse"
%define VENDOR SUSE
%else
%define VENDOR %_vendor
%endif

%description
Monit is a utility for managing and monitoring processes, files,
directories, and devices on a Unix system.  Monit conducts automatic
maintenance and repair and can execute meaningful causal actions in
error situations.  For example, monit can start a process if it does
not run, restart a process if it does not respond, and stop a process
if it uses too many resources.	You can use monit to monitor files,
directories, and devices for changes, such as time stamp changes,
checksum changes, or size changes. You can even use monit to monitor
remote hosts: monit can ping a remote host and check port connections.

%package doc
Summary:        Service Manager and Monitor System (Documentation and Examples)
Group:          System/Monitoring
%if 0%{?suse_version} > 1110
BuildArch:      noarch
%endif

%description doc
Monit is a utility for managing and monitoring processes, files,
directories, and devices on a Unix system.  Monit conducts automatic
maintenance and repair and can execute meaningful causal actions in
error situations.  For example, monit can start a process if it does
not run, restart a process if it does not respond, and stop a process
if it uses too many resources.	You can use monit to monitor files,
directories, and devices for changes, such as time stamp changes,
checksum changes, or size changes. You can even use monit to monitor
remote hosts: monit can ping a remote host and check port connections.

This package only contains the documentation and examples.
You must also install the package %{name} to actually use monit.

%prep
%setup -q -a100
%patch1
%patch2

find doc/ -type f -size 0 -exec %__rm {} \;

%build
export CFLAGS="%{optflags} -fno-strict-aliasing"
%configure \
	--with-ssl-lib-dir="%{_libdir}"

%__make %{?_smp_flags}

%install
%__make DESTDIR="%{buildroot}" install

%__install -d \
	"%{buildroot}/etc/init.d" \
	"%{buildroot}%{_sysconfdir}/%{name}.d" \
	"%{buildroot}%{_sbindir}" \
	"%{buildroot}%{_datadir}/%{name}" \
	"%{buildroot}%{_fillupdir}" \
	"%{buildroot}%{_monit_run_dir}" \
	"%{buildroot}%{_monit_run_dir}/events" \
	"%{buildroot}%{_localstatedir}/lib/%{name}"

. vendor-files/sysconfig/%{name}.tmpl
MONIT_BIN="%{_bindir}/%{name}"
MONIT_MODIFY_INITTAB="%{_datadir}/%{name}/%{name}-modifyinittab"
MONIT_PID_FILE="%{_monit_run_dir}/%{name}.pid"
MONIT_SYSCONFIG_FILE="/etc/sysconfig/%{name}"
MONIT_INITTAB_STATE_FILE="%{_localstatedir}/lib/%{name}/%{name}-inittab.state"
MONIT_ARGS="-p ${MONIT_PID_FILE} -s %{_monit_run_dir}/%{name}.state"
MONIT_EVENTQUE_DIR="%{_localstatedir}/lib/%{name}"
%__sed -e "s|%{_monit_run_dir}|${MONIT_EVENTQUE_DIR}|g" \
	< %{name}rc > "%{buildroot}%{_sysconfdir}/%{name}rc"

pushd vendor-files
for templatefile in docu/README tools/%{name}-modifyinittab init/%{name} sysconfig/%{name}; do
	%__sed \
		-e "s|__MONIT_RC_FILE__|${MONIT_RC_FILE}|g" \
		-e "s|__MONIT_INITTAB_BASE__|${MONIT_INITTAB_BASE}|g" \
		-e "s|__MONIT_INITTAB_COMMENT__|${MONIT_INITTAB_COMMENT}|g" \
		-e "s|__MONIT_INITTAB_STATE_FILE__|${MONIT_INITTAB_STATE_FILE}|g" \
		-e "s|__MONIT_ARGS__|${MONIT_ARGS}|g" \
		-e "s|__MONIT_BIN__|${MONIT_BIN}|g" \
		-e "s|__MONIT_MODIFY_INITTAB__|${MONIT_MODIFY_INITTAB}|g" \
		-e "s|__MONIT_PID_FILE__|${MONIT_PID_FILE}|g" \
		-e "s|__MONIT_SYSCONFIG_FILE__|${MONIT_SYSCONFIG_FILE}|g" \
		< "${templatefile}.tmpl" \
		> "${templatefile}"
done
popd # vendor-files

# systemd vs SysVinit
%if 0%{?has_systemd}
install -D -m 0644 %{S:3} %{buildroot}%{_unitdir}/%{name}.service
ln -sf %{_sbindir}/service %{buildroot}/%{_sbindir}/rc%{name}
%else #SysVinit
%__install -m0754 vendor-files/init/%{name} "%{buildroot}%{_sysconfdir}/init.d/%{name}"
%__ln_s %{_sysconfdir}/init.d/%{name} %{buildroot}%{_sbindir}/rc%{name}
%endif
%__install -m0644 vendor-files/sysconfig/%{name} "%{buildroot}%{_fillupdir}/sysconfig.%{name}"

%__install -m0754 vendor-files/tools/%{name}-modifyinittab "%{buildroot}%{_datadir}/%{name}"

touch "%{buildroot}%{_localstatedir}/lib/%{name}/%{name}-inittab.state"
%if 0%{?suse_version} == 0 || 0%{?suse_version} > 1110
touch "%{buildroot}%{_monit_run_dir}/.%{name}.id"
touch "%{buildroot}%{_monit_run_dir}"/%{name}.pid
touch "%{buildroot}%{_monit_run_dir}"/%{name}.state
%endif
%__install -m0644 vendor-files/docu/README README.SUSE

%__install -d "%{buildroot}%{_docdir}/%{name}"
>doc.main.lst
for f in COPYING; do
    %__install -m0644 "$f" "%{buildroot}%{_docdir}/%{name}/$f"
    echo "%doc %{_docdir}/%{name}/$f" >>doc.main.lst
done
>doc.doc.lst
for f in README* doc; do
    %__cp -a "$f" "%{buildroot}%{_docdir}/%{name}/"
    echo "%doc %{_docdir}/%{name}/$(basename $f)" >>doc.doc.lst
done

%pre
%if 0%{?has_systemd}
%service_add_pre %{name}.service
%endif

%preun
%if 0%{?has_systemd}
%service_del_preun %{name}.service
%else
%stop_on_removal %{name}
%endif

%post
%if 0%{?has_systemd}
%service_add_post %{name}.service
%{fillup_and_insserv -i}
%else
%{fillup_and_insserv}
%__install -d -m0700 -o root -g root %{_localstatedir}/run/%{name}
%__install -d -m0700 -o root -g root %{_localstatedir}/run/%{name}/events
%endif

%postun
%if 0%{?has_systemd}
%service_del_postun %{name}.service
%else
%restart_on_update %{name}
%{insserv_cleanup}
%endif

%files -f doc.main.lst
%defattr(-,root,root)
%doc %{_mandir}/man1/%{name}.1%{ext_man}
%doc %dir %{_docdir}/%{name}
%attr(0600,root,root) %config(noreplace) %{_sysconfdir}/%{name}rc
%dir %{_sysconfdir}/%{name}.d
%if 0%{?has_systemd}
%{_unitdir}/%{name}.service
%else
%attr(0754,root,root) %config %{_sysconfdir}/init.d/%{name}
%endif
%{_sbindir}/rc%{name}
%{_bindir}/%{name}
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/%{name}-modifyinittab
%{_fillupdir}/sysconfig.%{name}
%dir %{_localstatedir}/lib/%{name}
%ghost %{_localstatedir}/lib/%{name}/%{name}-inittab.state
%if 0%{?suse_version} == 0 || 0%{?suse_version} > 1110
%ghost %dir %{_monit_run_dir}
%ghost %{_monit_run_dir}/%{name}.pid
%ghost %{_monit_run_dir}/%{name}.state
%ghost %{_monit_run_dir}/.%{name}.id
%ghost %dir %{_monit_run_dir}/events
%endif

%files doc -f doc.doc.lst
%defattr(-,root,root)
%doc %dir %{_docdir}/%{name}

%changelog
* Thu Dec 14 2017 chris@computersalat.de
- remove double Req of %%insserv_prereq
* Wed Dec 13 2017 chris@computersalat.de
- fix for boo#1072692
  * monit: unable to start
  * add systemd monit.service file
  * still support SysVinit (SLE_11)
- update to 5.25.1
  * https://mmonit.com/monit/changes/
- rebase patches
  * monit-better_default_monitrc.patch
  * monit-rundir.patch
- format specfile
- more use of macros
* Thu Nov 23 2017 rbrown@suse.com
- Replace references to /var/adm/fillup-templates with new
  %%_fillupdir macro (boo#1069468)
* Fri Apr 21 2017 liedke@rz.uni-mannheim.de
- update to 5.22:
  + New: Linux: Added support for monitoring ZFS disk activity.
  + New: Added option to explicit specify if the HTTP method HEAD
    or GET should be used in a HTTP protocol test. If not
    specified, HEAD will be used unless a content or a checksum
    test is also specified, in which case GET is used instead.
    The default is normally what you want, but now you have the
    option to specificially use GET instead of HEAD.
  + New: File, Directory, Fifo checks: Added support for explicit
    testing access, change and modification time properties.
    If the type is not specified, the original timestamp test
    is performed, which checks the latest of ctime and mtime.
    It is also possible to use newer and older operators in the
    test now.
  + New: Renamed the statement, set logfile <path|syslog> to
  set log <path|syslog>.
  + Fixed: Linux: If the monitored filesystem was not found in
    /proc/diskstat, Monit could leak filedescriptors.
  + Fixed: Solaris on SPARC: Monit didn't trigger an event if a
    protocol test failed.
  + Fixed: Systemd template for Monit: Added StandardOutput=null
    option to prevent systemd to duplicate Monit log output.
  + Fixed: Monit cross-compilation
  + Fixed: configure --without-zlib
  + Fixed: If the connection test required STARTTLS, the certificate
    valid days test was broken.
  + Fixed: Compile on MacOSX 10.6.x - 10.9.x.
  + Fixed: HTTP protocol test: Allow using a request string in addition
    to path, to monitor e.g. a HTTP proxy.
  + Fixed: If connection or ping test repetition is set, log partial
    failures with warning priority instead of error.
  + Fixed: Linux: Support rootfs ramdisk.
  + Fixed: Connection retry was broken and performed the test only
    once with no retry on error.
  + Fixed: Linux: Subtract ZFS ARC size from the system memory usage.
  + Fixed: SSL certificate validity test and checksum test didn't work
    for self-signed certificates.
* Fri Mar 17 2017 liedke@rz.uni-mannheim.de
- update to 5.21:
  + New: We have added a set of new tests that you can use to monitor
    and check the performance of your file-systems and disks.
    Disk i/o metrics are also displayed in the Monit GUI and
    CLI. M/Monit 3.7.0 can be used to view statistics and charts.
  + New: We have also added disk i/o tests and metrics for each process.
    Available metrics depends on the platform.
  + New: You can now use NFS/CIFS/SSHFS/etc. connection strings as path
    for filesystem checks.
  + New: Report filesystem type in status output
  + New: Extended existence test to not only test if an object does not
    exist, but also the inverse, to test if an object does exist.
  + New: You can now set the SSL/TLS version to be used by the Monit
    HTTP interface. The syntax follows the general SSL/TLS options
    settings, which was introduced in Monit 5.15.
  + New: It is now possible to set the SSL/TLS ciphers Monit's HTTP
    server should use.
  + New: The certificate minimum valid days test now triggers the
    timestamp event instead of connection event.
  + New: M/Monit: show MacOS version instead of Darwin kernel version.
  + New: Show textual representation of filesystem flags instead of numeric.
  + Fixed: A lot of bugs.
* Wed Mar 15 2017 dimstar@opensuse.org
- PreReq %%insserv_prereq: we install legacy SyS-V init scripts and
  need to handle them. It's our own duty to ensure the legacy
  toolchain is present.
* Fri Nov  4 2016 liedke@rz.uni-mannheim.de
- update to 5.20:
  + New: Added gzip compression support to the HTTP GUI.
  + New: Added gzip compression when communicating with M/Monit.
  + New: Added global set onreboot <start | nostart | laststate>
  statement which allows to set a default service startup
  policy (the default is onreboot start).
  + New: Added new timeout options to the set limits statement:
  + New: The cpu, memory, swap, inode and space tests now allows
  using decimal values when testing percent usage.
  + New: Set the HOME environment variable when executing program
  as other user.
  + Fixed: CSRF vulnerability (CVE-2016-7067). (boo#1007455)
  + Fixed: A lot of bugs.
- update to 5.19:
  + New: Monit HTTP: support for IPv6 added.
  + New: Monit HTTP GUI: it is now possible to listen on both TCP
  and unix sockets.
  + New: apache-status protocol test:
  + New: Added Basic Authentication support to the HTTP protocol test.
  + Fixed: A lot of bugs.
* Mon Jun 27 2016 liedke@rz.uni-mannheim.de
- update to 5.18:
  + New: Monit console commands now output text in tables and in
    colors. Your terminal must support UTF-8 and colors. For
    best rendering of tables, we recommend using a fixed width
    font in your terminal such as Menlo for non-ascii fonts.
    Please see this FAQ entry to learn how to setup your console
    to support UTF-8 character encoding.
  + New: A new CLI command was added for succinct reporting and to make
    it easy to query Monit from scripts: monit report [options].
    Without option, prints a short overview of the state of all
    services managed by Monit.
  + New: Environment variable MONIT_SERVICE was added to check program
    scripts. The variable contains the name of the service
    (from monitrc) for which the program is executed.
  + New: A new onreboot statement was added for controlling service
    startup on reboot.
  + New: The old mode statement is reduced to active and passive. Where
    active mode provides automatic restart of service on error,
    while passive does not, and only provide alerts. Active mode
    is the default mode. The third mode, manual, is deprecated
    and replaced by onreboot laststate. The manual mode is still
    supported for backward compatibility.
  + New: Test for checking system uptime. Can be used to test the uptime
    of the system (boot time) and perform an action.
  + New: Added >= and <= as operators for use in comparison tests.
  + New: All errors will be listed if a service has multiple errors.
    Previously, Monit displayed only the last error.
  + Fixed: A lot of bugfixes...
* Mon Apr 11 2016 liedke@rz.uni-mannheim.de
- update to 5.17.1:
  + Fixed: Monit crashed when trying to deliver alert by mail if monit
    set alert was configured, but the set mail-format statement
  was missing (regression in Monit 5.17).
- update to 5.17:
  + New: Extended the SMTP protocol test to support STARTTLS in addition
  to SMTPS. Thanks to Robert Nelson for initial patch.
  + New: The SMTP protocol test can now, optionally, perform authentication
  during testing. Just add username and password if you want to test
  that authentication also works. We recommend using smtps if
  authentication is to be performed to encrypt the communication.
  + New: Support extended e-mail format when specyfing from and reply-to
  addresses. That is, instead of just the email address you can also
  specify the name of the user.
  + New: A new environment variable MONIT_PROGRAM_STATUS was added to check
  program to allow scripts called from exec to access the check programs
  last exit status.
  + Fixed: The include statement now check if a file has already been included
  to prevent circular or recursive inclusion of files.
  + Fixed: Reinitialize supplementary user groups in an exec action when
  executing as a different user.
  + Fixed: The value in if changed checksum and if changed timestamp has been
  made persistent across Monit restart/reload. If the value changes
  while Monit is stopped, Monit will now notice.
  + Fixed: Related to Issue #316 above, we now also save file size, filesystem
  flags, file/directory/fifo/filesystem permissions, network link speed
  so the last known values will be persistent and if changed tests will
  work as expected across a Monit restart/reload.
  + Fixed: favicon did not display properly in the Browser when Monit was behind
  a reverse HTTP proxy.
  + Fixed: Monit CLI actions like monit monitor all could fail if you had more
  than ~ 50 services in your config file.
  + Fixed: The send/expect protocol test returned error if the target server sent
  more data than the buffer limit.
  + Fixed: On 32-bit platforms with more then 4GB of RAM, Monit reported incorrect
  system and swap memory values (regression in Monit 5.16).
  + Fixed: Save state on exit when monit is executed in non-deamon mode.
* Fri Mar 18 2016 jgleissner@suse.com
- monit-rundir.patch: use /run/monit for pid file (bnc#971647)
- updated monit-better_default_monitrc.patch to set pid file
  correctly in /etc/monitrc
* Tue Feb  9 2016 liedke@rz.uni-mannheim.de
- update to 5.16:
  + New: Added a new statement for overriding default limits used by Monit.
  + New: Issue #276: Allow specific source address for port and ping tests.
  + New: Issue #205: Enhanced process check with a new thread counts test.
  + New: Issue #280: Timestamp tests now reports both the old and the new
    (changed) timestamp in alerts.
  + New: Issue #299: Show the last output of the program check when running
    monit status from the console.
  + New: Issue #275: monit --version now shows the compile-time features that
    were enabled at build time.
  + New: Issue #282: Added support for setting a custom URL path with
    apache-status protocol test.
  + New: Changed responsetime for port and unixsocket tests to microseconds
    precision.
  + New: Added support for DragonFly BSD. Thanks to Daniel Bilik.
  + Fixed: A lot of bugfixes
* Mon Jan 25 2016 liedke@rz.uni-mannheim.de
- update to 5.15:
  + New: Added a statement for setting global or local SSL/TLS options.
  + New: Added option to verify SSL server certificates.
  + New: Support SSL client certificate authentication for SSL connections.
  + New: To just connect using SSL/TLS without specifying a protocol, you can
    now use SSL instead of the former type TCPSSL statement
    (which is deprecated).
  + New: SSL certificate expiration test.
  + New: Extended SSL certificate fingerprint (checksum) test with the SHA1 hash
    type in addition to the existing MD5 test.
  + New: Extended the ping test to optionally allow setting a packet size
    (default is 64 bytes)
  + New: The ping tests now report network response time in milliseconds
    rather than in seconds.
  + New: PAM and SSL support are now optional when building Monit RPM.
  + Fixed: The File content match test will move the read-cursor to the end
    of the file the first time a file is added to Monit.
  + Fixed: Support for OpenSSL 0.9.8
  + Fixed: Abbreviated file permission error message (otherwise the message,
    which was rather long, could get truncated in logs and become
    unintelligible).
  + Fixed: Only add the User-Agent HTTP header if it is not already set.
    Also allow single quotes in addition to double quotes around
    header values.
  + Fixed: If a check host statement contains no if-tests, emit a more
    comprehensible error message.
  + Fixed: Do not log "Error reading pid from ..." for non-process checks
    on stop/restart.
  + Fixed: Monit could freeze for a period when performing a ping test.
  + Fixed: Do not cascade start action to dependant services if only parent
    start was requested.
  + Fixed: Implement hard dependency between services. If a service depends
    on another service, it will not start until the parent service
    check returns no errors. For example, if Apache depends on MySQL,
    Monit will not start Apache until MySQL is confirmed up and running
    and passes all its tests. Previously, Monit would start MySQL,
    but not wait for MySQL to be confirmed up and running before
    it started Apache.
  + Fixed: The HTTP protocol test paused Monit for a few seconds if a
    content match test was used and the server sent a response
    using chunked encoding.
  + Fixed: Monit no longer exit if it fails to fork. This is debatable,
    but for Monit's use-case we think it is better to try and continue.
  + Fixed: Monit leaked file descriptors if program execution failed.
    Don't forget the shebang #! at the beginning of your script
  + Fixed: Monit stopped on reload if the control file did not end with
    an empty newline.
  + Fixed: With OS X El Capitan, Apple introduced a new System Integrity
    Protection policy (SIP) which, among other things, block the
    system call, task_for_pid.We now check to see if SIP is enabled
    and if it is, we do not call task_for_pid so as not to unnecessary
    fill system logs with errors. This also means that Monit, on
    El Capitan, can no longer check a process memory and CPU usage
    as task_for_pid was needed to get this information.
  + Fixed: Executing a command with a timeout larger than 2147 seconds would
    fail on 32-bit systems.
  + Fixed: Mask out SSLv3_client_method() in case SSLv3 support is not available
  + Fixed: SSL SNI is optional, so do not log as error if not supported by server
  + Fixed: SSL client certificate authentication with Monit's HTTP interface
  + Fixed: Access to resources via secondary group membership when executing a
    program with a different UID
  + Fixed: Slow start/stop/restart/monitor/unmonitor actions on FreeBSD
- update to 5.14:
  + New: Enable HTTP Strict Transport Security (HSTS), ECDH ciphers and
    disable IDEA ciphers on Monit HTTP interface if TLS/SSL is used.
  + New: Simpler system-wide cpu usage test (total of user%%, system%%, wait%%).
  + New: Added options for the command-line commands monit status and monit
    summary to only print status for a named service or a named service group.
  + New: Log client address in case of HTTP request errors
  + New: Report Monit version in the start/stop (instance) message
  + Fixed:  MySQL test might produce "HOST blocked because of too many connection errors".
- update to 5.13:
  + New: Added support for free space and free inodes monitoring as an
    inverse alternative to current space/inodes consumption monitoring.
    Both forms, with absolute number of bytes and with percent are supported.
  + New: Added support for Server Name Indication to support testing connection to
    name based virtual SSL servers.
  + Security: SSL/TLS compression has been disabled, as well as RC4 and DES ciphers.
  + Fixed: Monit will no longer try to check hostnames on start-up to start faster,
    in case DNS is not available at start time.
  + Fixed: Filesystem uid, gid and permission as reported by monit status command.
  + Fixed: If the monit CLI command failed, the error description could contain
    HTML in addition to plaintext.
  + Fixed: RPM will now preserve an existing monitrc configuration file on update.
  + Fixed: OS X system memory usage statistics included wrongly inactive memory
    (i.e. memory that is available for reuse).
  + Fixed: FreeBSD, OpenBSD, NetBSD: System memory usage statistics did not
    include the wired part (kernel memory).
- update to 5.12.2:
  + Fixed: Monit could freeze if an error occurred during SSL read or write.
  + Fixed: If Monit was started with the HTTP interface disabled, the CLI could
    crashed when executing a command.
  + Fixed: Network check: support for IP alias [Linux and Solaris]
- update to 5.12.1:
  + New: Allow selecting IPv4 or IPv6 explicit for port and ping tests.
  + Fixed: The Upstart script needed to stop Monit earlier in the
    shutdown sequence when the system stops to prevent a
    possible race conditions
  + Fixed: Monit may crash if the hostname of the system failed to resolve.
  + Fixed: UDP connection test could fail on a dual-stack host
    (IPv4 and IPv6) if the UDP service listens on IPv4 only.
  + Fixed: Only show first line of program output in the Monit dashboard.
  + Fixed: Monit skipped the connection test if no start program was specified.
- update to 5.12:
  + New: Support for IPv6 hosts testing.
  + New: Monit HTTP interface now supports Unix Socket as an
    alternative to TCP port for easier deployment on virtualization
    platforms which share the IP address for containers, such
    as Docker. Thanks to Alberto Miorin for suggesting this feature.
  + New: The space usage test now ignore reserved blocks. Previously,
    Monit excluded reserved blocks from the free space, so it
    reported 100%% usage as soon as all non-super user accessible
    blocks were allocated, whereas the filesystem may still
    have some space available for root user (usually 1-5%%).
    The space usage test value will now match the output of utilities
    like df.
  + New: File permission change test added. Thanks to Ulrich
    Windl for suggesting this feature.
  + New: Support for multiple existence tests (in process, file,
    directory and fifo check contexts)
  + New: Support for multiple fsflag tests (in filesystem
    check context):
  + New: Monit's HTTP interface now provides even more
    details about failed HTTP requests
  + Fixed: Fix speed monitoring for 10Gb/s+ interfaces [Linux]
  + Fixed: Network total upload and download values could be invalid
    for certain time frames.
- update to 5.11:
  + New: Monit now supports monitoring of network interfaces.
  + New: Sieve protocol test implemented.
  + New: The PID and PPID change tests are no longer implicit and
    automatically executed.
  + New: Multiple PID and PPID tests can now be used.
  + Fixed: The CLI/GUI reported port timeout value in milliseconds
    instead of seconds.
  + Fixed: Changed memory kilobytes total title to memory
    total as the unit is dynamic since Monit 5.9.
  + Fixed: OpenBSD: don't narrow the 64-bit time_t on 32-bit
    build (Y2038 problem).
  + Fixed: If the the test is on hold due to the every option
    schedule, display last status instead of Waiting.
  + Fixed: If ping is not allowed (insufficient permissions),
    display value as N/A instead of negative response time.
  + Fixed: If the not every <cron> option matched, the test
    was skipped only once per minute.
  * Deleted: monit-dirs.patch
  * Updated: monit.spec
* Sat Nov 29 2014 lmuelle@suse.com
- update to 5.10:
  + New: Redis protocol test added.
  + New: MongoDB protocol test added.
  + New: Changes due to vulnerabilities in SSLv2 and SSLv3.
    See CVE-2014-3566 aka "POODLE".
  + Fixed: Issue #101: Manual-mode monitored services state may not be restored
    if the monitoring state was changed by user right before the system died.
  + Fixed: Issue #104: Keep umask Monit was started with when executing
    start/stop/restart programs, check programs and creating files.
  + Fixed: Issue #107: Support multi-line response in the LMTP protocol test.
  + Fixed: Support TLSv1.1 and TLSv1.2 when FIPS is enabled.
- update to 5.9:
  + New: Output from your check program script is now displayed in Monit’s UI.
  + New: Aggregate and use human friendly units for memory, swap and space
    usage values in the User Interface.
  + New: Support monitoring of filesystems by generic device strings such as
    sshfs on Linux or ZFS filesystems on Solaris.
  + New: You can now send HTTP headers with the HTTP protocol test.
  + New: Program check now supports exit status change monitoring.
  + New: Added option to run check program as a different user and/or group.
  + New: Changed name of ICMP ECHO statement to Ping which is the more common
    name used for a network ping.
  + New: Simplified HTTP and SMTP protocol test with SSL.
  + Fixed: Issue #59, Issue #88: Some systems with upstart (e.g. RHEL/CentOS)
    had problems with Monit's restart action which consists of a
    stop/start sequence.
  + Fixed: Issue #54: MySQL protocol test.
  + Fixed: Issue #64: Resets counter once a service has successfully restarted
  + New: Issue #84. You can now test for '\0' in an expect string.
  + Fixed: Issue #55: Only run cron style checks once per minute.
  + Fixed: Issue #78: Include open slots in Apache status check calculations
  + Fixed: Issue #57: Inode usage check and space usage check now show correct
    result for large filesystems on 32-bit platforms.
  + Fixed: Issue #70: Removed newline in Monit's $ENV strings
  + Fixed: Issue #72: Monit no longer requires a start, stop or restart
    program defined for a check.
  + Fixed: P.R. #17: Bug fix, missing "check file" target files result in error
    "Invalid checksum" sha1 has a string length of 40.
  + Fixed: P.R. #18: Add missing space in the timeout text in UI.
  + Fixed: Issue #71: Subtract SLAB reclaimable memory from the system memory
    usage on Linux
  + Fixed: Support TLSv1.1 and TLSv1.2 in "set mailserver"
  + Fixed: Sporadic "PPID changed from 0 to ..." alert after process restart
  + Fixed: PID/PPID changed events were sometimes triggered after program
    restart
  + Fixed: Linux: filesystem space usage on some network based filesystems
    such as sshfs
  + Fixed: Automatically reload Monit if ID was reset using --resetid CLI
    option.
  + Fixed: Improved speed of send/expect protocol test
  + Fixed: Fixed SMTP protocol test to check the response code
* Sat Nov 29 2014 lmuelle@suse.com
- Remove /var from path in rpmlintrc of the .monit.id file.
- Package /run only on post-11.1 systems.
* Sat Nov 29 2014 lmuelle@suse.com
- Modify shebang to point to bash where bash is required in
  vendor-files/tools/monit-modifyinittab.tmpl
- Align used SUSE trade name in the vendor-files.
* Wed Jul 30 2014 sfalken@opensuse.org
- update to 5.8.1:
  * Changed all /var/run to /run to fix rpmlint check failure in Factory
  * Added: monit-5.8.1.tar.gz
  * Deleted: monit-5.6.tar.gz
    monit-page_shift.patch as new version deprecates it
  * Updated: monit-better_default_monitrc.patch
* Wed Sep  4 2013 pascal.bleser@opensuse.org
- update to 5.6:
  * SMTP AUTH LOGIN support added (MS Exchange SMTP authentication should now
    work)
  * favicon.ico added to the HTTP interface
  * Bugfixes:
  - If an undefined checksum test was used and the file did not exist on
    Monit start, Monit would return an error
  - If the configuration file ended with a comment but with no trailing LF
    character, Monit would return syntax error
  - If a service timed out after too many restarts and alert was used as the
    action, then the Timeout flag remained set even if the service recovered
  - Escape mail messages properly for sending via SMTP
  - Escape XML messages properly
* Wed Jun  5 2013 lars@samba.org
- update to 5.5.1:
  * Info and debug messages are no longer sent to stderr, only to stdout.
  * Improved output from 'check program', If the program returns an error
    message, include only that message in alert $DESCRIPTION so users can
    compose their own alert format. If program provided no output on
    error, use a default message.
  * Improved "check system", $HOST can now be used as a service name.
    $HOST will expand to the system hostname. Example: check system $HOST
  * Fixed "Unable to read magic" which was reported on first Monit start.
* Tue Mar 12 2013 poelzleithner@b1-systems.de
- use relative path for dirname in init script. dirname is not
  longer in /bin, therefor the init script is broken
* Sun Nov  4 2012 lars@samba.org
- update to 5.5:
  * check program:
  - Multiple exit values can be tested within single program check
  - Exit value test supports multiple cycles option ("for X cycles")
  - If exit value test matches and the stderr has no data, try stdout
  * Renamed mail header (message-id and mime-version) to prevent
    triggering spam check of capitalization.
  * The 'check system <name>' statement sets the system hostname in mail
    alerts and initial hostname in M/Monit.
  * Increase the default mailserver timeout to 30 seconds.
  * Fix the rare hung on linux which may occur during program execution.
  * In the case that the process start/restart execution failed, monit kept
    "Execution failed" flag even if the process was recovered later (for
    example it was starting slowly or manually recovered).
  * Fix the mail alert (strict SMTP implementation) to pass MTA-side sanity
    checks like postscreen.
  * The -t option tests the configuration file syntax even if the
    file permissions are wrong.
  * Do not display the default non-existence test for the check
    program (not applicable in the check program context).
* Fri May 18 2012 lars@samba.org
- update to 5.4:
  * New process uptime test added.
  * The monit hostname will fallback to plain machine's hostname if the lookup
    for FQDN hostname didn't found matching entry.
  * The CPU usage for multi-threaded processes on multi-core machine was
    reported incorrectly in the case that the process used more CPU resources
    then equivalent to one core.
  * The content match test now sends one event per cycle and pattern.
  * The /proc/ files content match test was skipped, as the file size on the
    procfs is 0, so monit supposed that there is no content to read.
  * Allow reading status and perform Monit actions when using client SSL
    certificate.
  * When the process is starting/stopping, do the process state check more
    effectively to not stress the low power devices with aggresive polling.
  * Make the process start/stop wait resistant to large time changes.
  * Compilation: If PAM is enabled but the PAM headers or library are not
    found by the configure script, it will report error.
- BuildRequire pam-devel.
* Tue Mar  6 2012 cfarrell@suse.com
- license update: AGPL-3.0
  My mistake - there is no entry for AGPL-3.0+ on spdx.org/licenses. The
  only available one is AGPL-3.0 (without the plus)
* Wed Feb 29 2012 cfarrell@suse.com
- license update: AGPL-3.0+
  monit is AGPL-3.0 _not_ GPL-3.0
* Wed Jan 25 2012 pascal.bleser@opensuse.org
- fix bnc#743289 by adding monit-dirs.patch to set the PIDDIR accordingly to
  what is preset in the monitrc configuration (and in the spec file), as well
  as to fix the default event directory
* Wed Dec 21 2011 pascal.bleser@opensuse.org
- update to 5.3.2:
  * fix bug #34801: the file content match test did reset of the read position
    in the case that the unmonitor or stop action was done. When the file
    monitoring was enabled again, the content match test was applied to the
    content which was tested already.
  * log error details in the case that the name resolving failed
  * fix the system cpu usage statistics when pattern based process check is
    used and the service is restarted
  * Debian Bug#652715: "include files not found" warning: do not display the
    warning if the include directory is empty
- create /var/run/monit in the init script on start (if needed), as /var/run is
  on a volatile filesystem (tmpfs) since 12.1
* Tue Dec 13 2011 coolo@suse.com
- fix license to be in spdx.org format
* Wed Nov 30 2011 pascal.bleser@opensuse.org
- fixes to init script and configuration file for state file
- fix installation routine on >= 12.1: directories under /var/run are now
  created at installation time, as /var/run is on tmpfs on >= 12.1
- minor packaging improvements, including the use of the pristine upstream
  tarball instead of a recompressed one (better traceability)
* Fri Nov  4 2011 pascal.bleser@opensuse.org
- add some better defaults:
  * set mailserver to localhost
  * set alert recipient to root@localhost
  * enable event queue in /var/run/monit/events
  * move id and state files to /var/run/monit/
* Tue Oct 25 2011 pascal.bleser@opensuse.org
- update to 5.3.1:
  * log the particular connection attempt failure in debug mode when the retry
    is enabled
  * Monit can deliver events and status to independent M/Monit instances if
    multiple mmonit URLs are set
  * fixed: the ICMP echo (ping) test may report false positive error if the
    machine where Monit is running has heavy ICMP traffic generated by other
    applications
  * fixed: the file content match test will be performed even on the existing
    content when Monit starts; the last position is saved to the statefile, so
    monit won't generate alert after restart; note that when you start the
    monit 5.3.1 the first time, it can do actions for content match which was
    handled by previous monit version already as the previous monit versions
    didn't saved the position
  * make the monitoring state persistent for manual mode services
  * display the memory usage total %% in the status overview; the memory usage
    in kB displayed the total already, so the percentage didn't match
  * fix the HTML overview page alignment in the Internet Explorer
  * fix sporadic SSL routines:func(169):reason(161) errors
  * if MySQL protocol test failed, report the correct MySQL error code
- changes from 5.3.0:
  * new 'check program' statement added: allows to check the exit status of an
    external program or script from Monit
  * added crontab style support for individual services; you can now specify
    when an individual service should run its checks (or not run)
  * connection retry option added: allows to retry a network connection in the
    same testing cycle before reporting an error
  * detailed protocol connection errors are now included in alerts
  * the HTML overview page displays the CPU and memory total now (including
    children), so real service related usage is displayed also for services
    which spawn worker processes, such as Apache or Spamassassin
  * HTML view improvements
  * fix MySQL protocol test: MySQL 5.5.12 returns new error code in the case of
    authentication failure
  * the stacktrace logging on error is disabled in -v (verbose) mode as it was
    too verbose for common service debugging tasks, it can be enabled using -vv
    option
  * improve how fast Monit check if a program was started or stopped
  * fix the monitoring state presentation during service restart which
    temporarily displayed "Not monitored", whereas the monitoring was enabled
  * the "data collected" is updated only if the check was not skipped
* Tue Mar 29 2011 pascal.bleser@opensuse.org
- update to 5.2.5:
  * fix process match check - when the monitored process failed and was
    restarted by Monit, Monit didn't recognized it is running after the restart
    and reported  start failure (similar on stop)
  * fix Debian #617259: symbolic links in the filesystem check doesn't work
  * fix Debian bug #614984: smtp protocol test issues both EHLO and HELO
  * fix bug #32583: multiple SIP OPTIONS messages use the same header data
  * try harder to get FQDN hostname for the host where monit is running; the
    hostname in the $HOST variable which is used in the mail sender may thus
    change
  * support symbolic link to monit configuration file
  * fix crash when monit daemon start delay option was used and monit was
    signalized to stop before the start delay passed
* Mon Mar 21 2011 coolo@novell.com
- licenses package is about to die
* Tue Feb 22 2011 pascal.bleser@opensuse.org
- update to 5.2.4:
  * added the "procmatch" CLI command which allows for easy testing of pattern
    for process match check
  * set the default log file mask to 0640 (originally it was 0664)
  * reduced monit memory footprint by ca. 10%%.
  * fix memory usage monitoring in OpenVZ VPS 2.6.32 virtual hosts
  * if the protocol test failed, show the request in the event
  * randomize the mail message id to prevent duplicates in the case, that the
    same hostname is used on multiple hosts running monit and messages are
    generated in the same second in parallel
* Thu Sep 23 2010 pascal.bleser@opensuse.org
- fixed typo in init script, "description" -> "Description"
- added missing dependency on $remote_fs in init script
- dropped monit-no_strip.patch, as upstream doesn't forcibly strip symbols any more
- /var/run/monit is now created at runtime, in order to work properly if /var/run is on tmpfs
- documentation split out into -doc subpackage
- update to 5.2:
  + new features:
  * added support for monitoring processes without pidfile using pattern matching
  * added support for swap monitoring
  * allow to override the default action when service doesn't exist
  * Monit automatically registers credentials with M/Monit now, so it's not necessary to set it manually in M/Monit anymore
  * added memcache protocol test
  * added openssl FIPS to Monit httpd
  * the 'check system' can now use start/stop program statements too
  * added the option to set the "Reply-To" mail header in mail-format
  * display backtrace on error if debug mode is enabled (requires backtrace support in libc)
  + bugfixes:
  * show real process uptime - formerly the presented uptime was based on create and modify timestamp of process' pidfile which provides invalid uptime if the pidfile is replaced and process keeps running with original PID
  * when user triggered action for some service (such as stop) and before that action completed user triggered another action for the same service (such as start), the second action has been ignored. Monit will not accept new action and return temporary error until the previous action completed
  * if process resource usage gathering failed, retry next cycle as the error can be temporary
  * fixed sporadic failures when SSL was used
  * ICMP echo test (ping):
  - fixed sporadic false positive/negative
  - removed limit of 20 pings per cycle
  * DNS test:
  - accept NS root request refusal as correct response because server reacts on request
  - accept authority answer as alternative to record
  * RADIUS test fix
  * M/Monit heartbeat is fully independent of testing cycle now to prevent false positive when service test blocks
  * fixed SMTP STARTTLS protocol, required for servers that adhere strictly to RFC 3207 4.2
  * service name:
  - allow the service name to start with "/"
  - fixed handling of the service names which contain "/" in the name in Monit web interface
  * when 'check system' is not defined, monit adds it automatically using hostname for service name
  * remove extra NL characters from message when resource succeeded event is sent
  * fixed display of cpu user/system/wait usage which temporarily displayed -1.0%% between two monitoring cycles while cpu monitoring was initializing
  * fixed display of port response time as -1 if 'monit status' was called in the middle of service test
  * fixed display of service initializing state after monit start or reload
  * fixed MONIT_DESCRIPTION environment variable
* Tue Aug 10 2010 lmuelle@suse.de
- Remove merged superfluous hz patch.
* Tue Aug 10 2010 lmuelle@suse.de
- Add Should-Start $syslog $time $named to the init script; (bnc#553082).
* Tue Feb 23 2010 pascal.bleser@opensuse.org
- update to 5.1.1:
  * several more protocol tests and bugfixes were added
* Tue Nov  3 2009 coolo@novell.com
- updated patches to apply with fuzz=0
* Wed Sep 30 2009 pascal.bleser@opensuse.org
- update to 5.0.3
* Thu Apr 16 2009 pascal.bleser@opensuse.org
- update to 5.0
* Fri Nov  9 2007 crrodriguez@suse.de
- update to version 4.10.1 (massive feature,bugfix release see CHANGES.txt for more details)
- add missing PreReq tags to fix build in BETA
- add missing remote_fs dependency in the init script
* Tue Nov  6 2007 guru@unixtech.be
- update to 4.10
* Thu Sep 20 2007 guru@unixtech.be
- moved to openSUSE Build Service
* Thu Mar 29 2007 rguenther@suse.de
- add bison and flex BuildRequires
* Sat Mar 24 2007 guru@unixtech.be
- new package, based on SUSE/Factory's monit source RPM (2007-03-24)
* Mon Aug  7 2006 ro@suse.de
- define HZ sysconf(_SC_CLK_TCK) if not defined
* Sat May 27 2006 lmuelle@suse.de
- Update to version 4.8.1 (bugfix release; see CHANGES.txt for more details).
  * Fix logging on 64-bit systems.
  * Don't stop if there is no space on the filesystem.
  * Remove the false warning about TOTALMEMORY.
* Fri Apr 21 2006 lmuelle@suse.de
- Use /var/lib/monit to store the inittab state file.
* Tue Apr 18 2006 lmuelle@suse.de
- Use kill instead of killproc to terminate monit if we start monit from
  inittab.
- Add /etc/monit.d and /var/lib/monit directories.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Jan 20 2006 schwab@suse.de
- Don't strip binaries.
* Fri Jan 13 2006 lmuelle@suse.de
- Update to version 4.7.
* Thu Oct 27 2005 lmuelle@suse.de
- Update to version 4.6.
* Thu Apr 14 2005 lmuelle@suse.de
- Update to version 4.5.1.
* Mon Apr 11 2005 lmuelle@suse.de
- Update to version 4.5.
* Mon Oct 11 2004 lmuelle@suse.de
- Update to version 4.4.
* Fri Sep 10 2004 lmuelle@suse.de
- Remove update notify message, [#44356].
- Move vendor files to an own tar ball.
* Fri May 14 2004 lmuelle@suse.de
- Update to version 4.3.
* Tue Apr 20 2004 lmuelle@suse.de
- Update to version 4.2.1, [#39166]
* Wed Jan  7 2004 lmuelle@suse.de
- update to version 4.1.1
- allow call of /usr/share/monit/monit-modifyinittab without a switch
- add /usr/share/monit/monit-modifyinittab as Command: to sysconfig file
* Mon Nov 10 2003 lmuelle@suse.de
- rename SuSEconfig.monit to /usr/share/monit/monit-modifyinittab
- add --add and --remove switch to /usr/share/monit/monit-modifyinittab
- call /usr/share/monit/monit-modifyinittab in the init script if
  MONIT_VIA_INITTAB of /etc/sysconfig/monit is set to "yes"
* Sat Nov  8 2003 lmuelle@suse.de
- use 0600 for /etc/monitrc
- add systax check to init and SuSEconfog.monit script
- don't check for configuration file or syntax if the init script is called
  with 'stop'
* Fri Nov  7 2003 lmuelle@suse.de
- update to version 4.1
- add restart on update and other usual macros to %%preun and %%postun
- add poll option to the init script to send SIGUSR1
- add a vendor README
- add norootforbuild to the spec file
* Wed Oct  1 2003 schwab@suse.de
- Don't use PAGE_SHIFT.
* Mon Jun  2 2003 lmuelle@suse.de
- inital SuSE RPM based on the spec file provided by the monit team
